pub async fn get_json<T: DeserializeOwned + 'static>(
url: impl Into<String>,
) -> Result<T>Expand description
Performs a GET request to url and deserializes the response body from
JSON into T.
pub async fn get_json<T: DeserializeOwned + 'static>(
url: impl Into<String>,
) -> Result<T>Performs a GET request to url and deserializes the response body from
JSON into T.